#
# spec file for package ProtonPlus
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid com.vysp3r.ProtonPlus
Name:           ProtonPlus
Version:        0.5.5
Release:        1.1
Summary:        A Wine and Proton-based compatibility tools manager for GNOME
License:        GPL-3.0-only
URL:            https://github.com/vysp3r/ProtonPlus
Source:         %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  appstream-glib
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  git-core
BuildRequires:  meson >= 1.0.0
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.5.0
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libsoup-3.0)

%description
ProtonPlus is a Proton version manager for installing and managing Proton
versions. It works with Steam, Lutris, Heroic Games Launcher and Bottles. It
uses GTK4.

%lang_package

%prep
%autosetup

%build
%meson --prefix=/usr
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes %{buildroot}

%check
%meson_test

%files
%{_bindir}/protonplus
%{_datadir}/metainfo/%{appid}.metainfo.xml
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/*/apps/%{appid}.png

%files lang -f %{appid}.lang

%changelog
* Fri Jun 20 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.5:
  * Fix profile detection (for real)
- update to 0.5.4:
  * Fix profile detection
- update to 0.5.3:
  * Add the ability to change the launch options
  * Add a feature list in README
  * Adding more options to game rows
  * Add the ability to set the default compatibility tool for Steam
  * Update translations
* Tue Jun 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.2:
  * Fixed Kron4ek Proton downloads
  * Fix ProtonDB logo not appearing with light theme
  * Fix shortcut button
  * Allow to unselect a game by clicking on it
  * Improve game library UX
* Mon Jun  9 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.1+1:
  * Fixed Kron4ek Proton downloads
- update to 0.5.1:
  * Fixed musl libc compilation
  * Fixed Kron4ek Proton builds
* Sun Jun  8 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.5.0+1:
  * fix metainfo.xml file
- update to 0.5.0:
  * Added Kron4ek Proton builds
  * Added a way to add a shortcut of ProtonPlus in Steam
  * Added a way to see if a compatibility tool is used or not for Steam
  * Added the ability to change the compatibility tool of Steam games
  * Added the ability to change the compatibility tool of multiple Steam game
    at the same time
  * Fix UI freeze when installing/removing STL
  * Improved the UX of most of the dialogs
* Wed Jun  4 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.32:
  * rename binary to protonplus
  * Translations updates
  * data/meson.build: modify AppData validation
  * README.md: update Fedora dependencies
- add rudimentary tests
- switch to download_files service
* Mon May 26 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.31:
  * Update french translation
  * Update german translation
  * Add Traditional Chinese translation
* Tue May 20 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.30:
  * Add support for Proton-EM
- update to 0.4.29:
  * Fix only Steam showing up
- update to 0.4.28:
  * Update Chinese translation and improve localization
  * Update runtime to GNOME 48
  * Added a check for inactive Steam installation
* Wed Mar 12 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.27:
  * Remove old runners
  * Reorder runners
  * update german translation
* Mon Mar 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.26:
  * Add Proton-CachyOS
  * Update translations
* Mon Feb 24 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.25:
  * Fix DXVK names
  * Fix German localization typo
* Mon Feb 17 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.24:
  * Add missing translatable labels
  * Update german translation
  * Fix HGL support
- update to 0.4.23:
  * Update czech translation
  * Update german translation
  * Fix Proton-Sarek
- update to 0.4.22:
  * Fix libadwaita version minimum requirement
* Sun Feb 16 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.21:
  * Update russian translate
  * Update german translation
  * Update README.md
  * Add additonal utility category
  * Refactoring of the whole application
* Sat Oct  5 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.20:
  * Generate PNG icons for desktop environments with bad SVG support
  * Use PNG app icons instead of SVG
- update to 0.4.19:
  * Fix Proton-Sarek
  * Update description to include Sarek
  * Add keywords to metainfo
- update to 0.4.18:
  * Refresh application logo with more shading and modern border
  * Add Sarek
  * Update Swedish translation
* Tue Sep 17 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.17:
  * Updated German translation
* Fri Sep 13 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.16:
  * Added support for Steam Tinker Launch
  * Made Ctrl-Q quit the application
  * The window now remembers the last-used size
  * Improved UI polish and consistency
  * Made it easier to translate the application
  * Added developer scripts
  * Add swedish translation
* Thu Jul 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.4.15:
  * fix mistake
- update to 0.4.11:
  * update translations
  * Remove extra space in bottles.vala
* Fri May 10 2024 Richard Rahl <rrahl0@disroot.org>
- update to 0.4.10:
  * Update GNOME runtime to version 46
  * Add rtsp variant of ge proton
* Tue Jan 23 2024 Richard Rahl <rrahl0@proton.me>
- change services to manual
- add a minimum meson version
* Sun Dec 10 2023 Richard Rahl <rrahl0@proton.me>
- fix a bug which didn't show installed wine/proton versions
* Wed Nov 29 2023 Richard Rahl <rrahl0@proton.me>
- update to version 0.4.8:
  * Fix Bottle Icon
* Thu Nov 23 2023 Richard Rahl <rrahl0@proton.me>
- Update to version 0.4.7-2:
  * Modified the appdata file to include the changelog of v0.4.7
- Update to version 0.4.7-1:
  * Fix missing icon sizes.
- Update to version 0.4.7:
  * modernised UI
  * updated localization
* Tue Sep  5 2023 Richard Rahl <rrahl0@proton.me>
- update to version 0.4.6:
  * Add Installed filter
  * Add couple extra Wine/DXVK versions for download
* Mon Jul 31 2023 Richard Rahl <rrahl0@proton.me>
- Seperate language files into their own package
- Update to version 0.4.5:
  * Reworked delete diaglog
  * Added ability to download older Wine/Proton versions
  * Updated localization
* Sat Jul  8 2023 Richard Rahl <rrahl0@proton.me>
- Add libarchive and libjson-glib-1_0-0 as dependency
* Tue Jul  4 2023 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Wed Jun 14 2023 rrahl0@proton.me
- Update to version 0.4.4:
  * :hammer: Update appdata
  * :bug: Fix Proton Tkg
  * :bug: Fix install directories creation
  * Update  german translation
* Tue Jun 13 2023 rrahl0@proton.me
- Update to version 0.4.3:
  * :bug: Fix warning box
  * :memo: Fix appdata typo
  * :lipstick: Updated the UI
  * :globe_with_meridians: Update language files
  * :wrench: Update appdata and meson
  * :sparkles: Added caching system
  * Add german translation
